export * from './api';
export declare const BIND_TYPE: {
    sceneControl: number;
    sceneDimming: number;
    lightControl: number;
    curtainControl: number;
    airConditionerControl: number;
    tvControl: number;
    virtualControl: number;
    musicControl: number;
    voiceCentralControl: number;
    distributeBle: number;
    bleDimming: number;
    bleLight: number;
    bleCurtain: number;
};
interface DeviceSelectParams {
    /**
     * 绑定类型
     * @description {1: '场景控制', 2: '场景调光', 3: '灯光控制', 4: '窗帘控制', 5: '空调控制', 6: '电视控制', 7: '非智能灯', 8: '音乐控制', 9: '语音中控', 10: '非智能灯', 11: '蓝牙调光', 12: '蓝牙灯', 13: '蓝牙窗帘'}
     */
    type: typeof BIND_TYPE[keyof typeof BIND_TYPE];
    /**
     * 按键 ID
     * @type {string}
     * @description 当前按钮在当前设备的索引(button_install_x)
     */
    buttonId: string;
    /**
     * 当前按钮对应的dpId
     */
    dpId: number;
    /**
     * 当前按钮对应的 dp code
     */
    code: string;
    /**
     * 当前家庭ID, ty.home.getCurrentHomeInfo
     */
    homeId?: number;
    /**
     * 对内容进行预设，现只支持 actions 字段。
     * 示例：
     * {
     *  actions: {
     *   1: {icon: require('path'), title: '灯光1', desc: '描述1'},
     *   2: {icon: require('path'), title: '灯光2', desc: '描述2'},
     *  [bindType]: {icon: require('path'), title: '灯光3', desc: '描述3'},
     * }
     */
    preset?: Record<string, any>;
}
/**
 * 打开设备选择或调光选择
 */
export declare function openDeviceOrDimmingSelect(params: DeviceSelectParams): Promise<void>;
type SceneSelectParams = Omit<DeviceSelectParams, 'type'>;
/**
 * 打开场景选择（一键执行）
 */
export declare function openSceneSelect(params: SceneSelectParams): Promise<void>;
type VirtualDeviceBindParams = Omit<DeviceSelectParams, 'type'> & {
    /**
     * 当前按钮对应的群组执行dpId, 查看绑定详情时不需要传
     */
    groupExecuteDpId?: number;
    /**
     * 绑定规则(绑定详情时传)
     */
    bindRule?: any;
};
export declare function openVirtualDeviceBind(params: VirtualDeviceBindParams): Promise<void>;
type BindDetailParams = Omit<DeviceSelectParams, 'type'> & {
    /**
   * 绑定规则(绑定详情时传)
   */
    bindRule?: any;
};
export declare function openBindDetail(params: BindDetailParams): Promise<void>;
